==> sv_v0.15.tgz: supervisor/viewlog.sh <==
#!/bin/sh
LOG=$1
VIEWLOG=viewlog
TMP=$VIEWLOG.tmp
grep -- \ -\> $LOG | awk '{print $1,$2,$3,$4,$5}' >$TMP.forw
grep -- \ \<\- $LOG | grep -v " wait="| sort -k4 -g| awk '{print $1,$2,$3,$4}' >$TMP.back
join -1 4 -2 4 $TMP.forw $TMP.back|sed -e 's/:/ /g' -e 'sx->xx'>$TMP.log
	awk '{t1=$3+$4/60.+$5/3600.;t2=$9+$10/60.+$11/3600.; \
	if ($2!=$8)	{t2+=24};t=(t1+t2)/2;dt=(t2-t1)/2;if (dt==0) {dt=0.00001};\
	print $6,$7,t,dt}' $TMP.log >$TMP.in

N=0
for dat in `cat $VIEWLOG.typ| sort -gr |grep -v \#| sed -e 's/\ /-/g'`; do
	pat=`echo $dat|sed -e 's/[^-]*-//' -e 's/-/\ /g' -e 's/^\ *//'`
	y=`echo $dat|sed 's/-.*$//'`
	echo "set $N: $pat at $y"
	grep "$pat" $TMP.in | awk -v y=$y '{print $3,y,$4}' >$TMP.$N
	sed "s/s$N.*legend.*$/s$N\ legend\ \"$pat\"/" $VIEWLOG.par >$TMP.leg
	N=`echo "$N 1 + p q"|dc`
done
# Modify title:
date=`grep session\ open $LOG|tail -n 1|awk '{print $1}'`
sed s/title.*SV\ communication\ log.*/title\ \"SV\ communication\ log\ for\ $date\"/\
	$VIEWLOG.par >$TMP.leg; 
mv $TMP.leg $VIEWLOG.par
# xy-range:
min=`awk '{print $3}' $TMP.in | sort -g |head -n 1`
max=`awk '{print $3}' $TMP.in | sort -g |tail -n 1`
xmin=`dc -e "7 k $min $max $min - 20.00 / - p"`
xmax=`dc -e "7 k $max $min - 20 / $max + p"`
min=`grep -v \# $VIEWLOG.typ| awk '{print $1}' | sort -g | head -n 1`
max=`awk '{print $1}' $VIEWLOG.typ | sort -g | tail -n 1`
ymin=`dc -e "7 k $min $max $min - 20 / - p"`
ymax=`dc -e "7 k $max $min - 20 / $max + p"`
xmgrace -param $VIEWLOG.par -settype xydx -noask -world $xmin $ymin $xmax $ymax \
	-autoscale none $TMP.[0-9]
rm $TMP.*

==> sv_v0.17.tgz: supervisor/viewlog.sh <==
#!/bin/sh
LOG=$1
VIEWLOG=viewlog
TMP=$VIEWLOG.tmp
grep -- \ -\> $LOG | awk '{print $1,$2,$3,$4,$5}' >$TMP.forw
grep -- \ \<\- $LOG | grep -v " wait="| sort -k4 -g| awk '{print $1,$2,$3,$4}' >$TMP.back
join -1 4 -2 4 $TMP.forw $TMP.back|sed -e 's/:/ /g' -e 'sx->xx'>$TMP.log
	awk '{if (curdate==0) {curdate=$2; dd=0}; \
	if ($2!=curdate) {curdate=$2; dd+=1};
	t1=dd*24+$3+$4/60.+$5/3600.;t2=dd*24+$9+$10/60.+$11/3600.; \
	if ($2!=$8)	{t2+=24};t=(t1+t2)/2;dt=(t2-t1)/2;if (dt==0) {dt=0.00001};\
	print $6,$7,t,dt}' $TMP.log >$TMP.in

N=0
for dat in `cat $VIEWLOG.typ| sort -gr |grep -v \#| sed -e 's/\ /-/g'`; do
	pat=`echo $dat|sed -e 's/[^-]*-//' -e 's/-/\ /g' -e 's/^\ *//'`
	y=`echo $dat|sed 's/-.*$//'`
	echo "set $N: $pat at $y"
	grep "$pat" $TMP.in | awk -v y=$y '{print $3,y,$4}' >$TMP.$N
	sed "s/s$N.*legend.*$/s$N\ legend\ \"$pat\"/" $VIEWLOG.par >$TMP.leg
	N=`echo "$N 1 + p q"|dc`
done
# Modify title:
date=`grep session\ open $LOG|tail -n 1|awk '{print $1}'`
sed s/title.*SV\ communication\ log.*/title\ \"SV\ communication\ log\ for\ $date\"/\
	$VIEWLOG.par >$TMP.leg; 
mv $TMP.leg $VIEWLOG.par
# xy-range:
min=`awk '{print $3}' $TMP.in | sort -g |head -n 1`
max=`awk '{print $3}' $TMP.in | sort -g |tail -n 1`
xmin=`dc -e "7 k $min $max $min - 20.00 / - p"`
xmax=`dc -e "7 k $max $min - 20 / $max + p"`
min=`grep -v \# $VIEWLOG.typ| awk '{print $1}' | sort -g | head -n 1`
max=`awk '{print $1}' $VIEWLOG.typ | sort -g | tail -n 1`
ymin=`dc -e "7 k $min $max $min - 20 / - p"`
ymax=`dc -e "7 k $max $min - 20 / $max + p"`
xmgrace -param $VIEWLOG.par -settype xydx -noask -world $xmin $ymin $xmax $ymax \
	-autoscale none $TMP.[0-9]
rm $TMP.*
